@@ -61,11 +61,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.510
+Version 0.511
 
 =cut
 
-our $VERSION = '0.510';
+our $VERSION = '0.511';
 
 
 =head2 Development status
@@ -684,8 +684,8 @@ Dochazka data can be seen to exist in the following classes of objects:
 
 =over
 
-=item * Policy (parameters set when database is first created)
-
+##=item * Policy (parameters set when database is first created)
+##
 =item * Employee (an individual employee)
 
 =item * Privhistory (history of changes in an employee's privilege level)
@@ -700,6 +700,8 @@ Dochazka data can be seen to exist in the following classes of objects:
 
 =item * Locks (determining whether a reporting period is locked or not)
 
+=item * Components (Mason components, i.e. report templates)
+
 =back
 
 These classes are described in the following sections.
@@ -908,6 +910,22 @@ of time (weeks, months, years . . .) at once, if that is deemed expedient.
 For details, see L<App::Dochazka::REST::Model::Lock>.
 
 
+=head2 Component
+
+L<Reports are generated/"REPORT GENERATION"> from
+L<Mason|https://metacpan.org/pod/Mason> templates which consist of
+components. Mason expects these components to be stored in text files under
+a directory called the "component root". For the purposes of Dochazka, the
+component root is created under the Dochazka state directory, which is
+determined from the C<DOCHAZKA_STATE_DIR> site parameter (defaults to
+C</var/lib/dochazka>). When the server starts, this Mason state in the
+filesystem is wiped and re-created from the database. The C<Component>
+class is used to manipulate Mason components.
+
+This rather complicated setup is designed to enable administrators to
+develop their own report templates.
+
+
 
 =head1 INSTALLATION
 
@@ -1304,7 +1322,10 @@ debug messages will be logged.
 
 =back
 
-=head1 METHODS
+
+
+
+=head1 FUNCTIONS
 
 
 =head2 run_sql
